## Odia

Odia is Python library for the Odia language which is an Indo-Aryan language spoken in the Indian state of Odisha. It is the official language in Odisha where native speakers make up 82% of the population, also spoken in parts of West Bengal, Jharkhand, Chhattisgarh, and Andhra Pradesh.

The Odia script (Odia: କଳିଙ୍ଗ ଲିପି; also known as the Kalinga script) is a Brahmic script used to write primarily Odia language and less frequently Kui, Santali, Ho and Chhattisgarhi. The script has developed over more than 1000 years. The earliest trace of the script has been dated to 1051 AD. It is a syllabic alphabet or an abugida, wherein all consonants have an inherent vowel embedded within.



```bash
[ସ୍ୱର ବର୍ଣ୍ଣ]
ଅ ଆ ଇ ଈ ଉ ଊ ଋ ୠ ଏ ଐ ଓ ଔ 



[ବ୍ୟଞ୍ଜନ ବର୍ଣ୍ଣ]
କ	ଖ	ଗ	ଘ	ଙ

ଚ	ଛ	ଜ	ଝ	ଞ

ଟ	ଠ	ଡ	ଢ	ଣ

ତ	ଥ	ଦ	ଧ	ନ

ପ	ଫ	ବ	ଭ	ମ

ଯ	ୟ	ର	ଳ	ଲ

ଵ   ଶ	ଷ	ସ	ହ

କ୍ଷ	ଜ୍ଞ




୦ ୧ ୨ ୩ ୪ ୫ ୬ ୭ ୮ ୯



```



### Features

* Print Odia characters
* Print Odia numbers



### Installation with pip

```bash
pip install odia
```




### How to use

```python
import odia

print(f'version : {odia.__version__}')
```



### Author

[Biranchi Narayan Nayak](https://www.biranchi.com) (<biranchi125@gmail.com>) [maintainer, developer]


 
### Contribution

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.




### License

[MIT](https://choosealicense.com/licenses/mit/)



